# Skepticoin's Design Principles

Skepticoin is the Coin for non-believers. Its design principles follow directly from that:

* **simplicity**: Bitcoin and its clones thrive on [overcomplicated technobabble](philosophy/principles.md). To pull the
  veil we strive for the opposite: a Coin that is as simple as possible.

* **unoriginality**: Altcoin creators generally strive to be somehow unique in an attempt to make people think their
  coin might be the Next Big Thing. Skepticoin does the opposite. Rather than making you wonder whether it is the Next
  Big Thing, it makes you wonder whether any of the previous ones ever were.

* **incompleteness**: If the unofficial slogan of Bitcoin is "to relive 500 years of financial catastrophes in a
  decade", Skepticoin's slogan is to relive Bitcoin's in an ever shorter timespan.
